@@ -60,46 +60,46 @@ namespace Oxygen
 
         Q_OBJECT
 
-        //! declare glow intensity property
+        //* declare glow intensity property
         Q_PROPERTY( qreal glowIntensity READ glowIntensityUnbiased WRITE setGlowIntensity )
 
         public:
 
-        //! constructor
+        //* constructor
         Client(KDecorationBridge *b, Factory *f);
 
-        //! destructor
+        //* destructor
         virtual ~Client();
 
-        //! decoration name
+        //* decoration name
         virtual QString visibleName() const;
 
-        //! buttons
+        //* buttons
         virtual KCommonDecorationButton *createButton(::ButtonType type);
 
-        //!@name flags
+        //*@name flags
         //@{
 
-        //! true if decoration has iquired behavior
+        //* true if decoration has iquired behavior
         virtual bool decorationBehaviour(DecorationBehaviour behaviour) const;
 
-        //! true if window is maximized
+        //* true if window is maximized
         virtual bool isMaximized( void ) const
         { return maximizeMode()==MaximizeFull && !configuration()->drawBorderOnMaximizedWindows();  }
 
-        //! true if animations are used
+        //* true if animations are used
         bool animationsEnabled( void ) const
         { return _configuration->animationsEnabled(); }
 
-        //! true if glow is animated
+        //* true if glow is animated
         bool glowIsAnimated( void ) const
         { return _glowAnimation->isRunning(); }
 
-        //! true when decoration is forced active
+        //* true when decoration is forced active
         bool isForcedActive( void ) const
         { return _forceActive && tabCount() > 1; }
 
-        //! true when separator is to be drawn
+        //* true when separator is to be drawn
         bool drawSeparator( void ) const
         {
             if( _configuration->drawTitleOutline() ) return false;
@@ -118,7 +118,7 @@ namespace Oxygen
 
         }
 
-        //! true if titlebar is hidden
+        //* true if titlebar is hidden
         bool hideTitleBar( void ) const
         {
             return
@@ -129,17 +129,17 @@ namespace Oxygen
 
         //@}
 
-        //! window shape
+        //* window shape
         virtual void updateWindowShape();
 
-        //! initialization
+        //* initialization
         virtual void init();
 
-        //! return associated configuration
+        //* return associated configuration
         Factory::ConfigurationPtr configuration( void ) const
         { return _configuration; }
 
-        //!@name glow animation
+        //*@name glow animation
         //@{
 
         void setGlowIntensity( qreal value )
@@ -149,105 +149,105 @@ namespace Oxygen
             widget()->update();
         }
 
-        //! unbiased glow intensity
+        //* unbiased glow intensity
         qreal glowIntensityUnbiased( void ) const
         { return _glowIntensity; }
 
-        //! glow bias
+        //* glow bias
         static qreal glowBias( void )
         { return 0.2; }
 
-        //! true (biased) intensity
-        /*! this is needed to have glow go from either 0.2->1 or 0.8->0 depending on the animation direction */
+        //* true (biased) intensity
+        /** this is needed to have glow go from either 0.2->1 or 0.8->0 depending on the animation direction */
         qreal glowIntensity( void ) const
         { return _glowAnimation->direction() == Animation::Forward ? _glowIntensity : _glowIntensity-glowBias(); }
 
         //@}
 
-        //! helper class
+        //* helper class
         DecoHelper& helper( void ) const
         { return _factory->helper(); }
 
-        //! helper class
+        //* helper class
         ShadowCache& shadowCache( void ) const
         { return _factory->shadowCache(); }
 
-        //!@name metrics and color definitions
+        //*@name metrics and color definitions
         //@{
 
-        //! dimensions
+        //* dimensions
         virtual int layoutMetric(LayoutMetric lm, bool respectWindowState = true, const KCommonDecorationButton * = 0) const;
 
-        //! get title rect for untabbed window
+        //* get title rect for untabbed window
         virtual QRect defaultTitleRect( bool active = true ) const;
 
-        //! get title bounding rect
+        //* get title bounding rect
         virtual QRect titleBoundingRect( const QFont& font, const QString& caption ) const
         { return titleBoundingRect( font, titleRect(), caption ); }
 
-        //! get title bounding rect
+        //* get title bounding rect
         virtual QRect titleBoundingRect( const QFont&, QRect, const QString& ) const;
 
-        //! palette background
+        //* palette background
         QPalette backgroundPalette( const QWidget*, QPalette ) const;
 
-        //! background
+        //* background
         QColor backgroundColor( const QWidget* widget, QPalette palette ) const
         { return backgroundColor( widget, palette, isActive() || isForcedActive() ); }
 
-        //! background
+        //* background
         QColor backgroundColor( const QWidget*, QPalette, bool ) const;
 
         //@}
 
-        //! title alignment
+        //* title alignment
         inline Qt::Alignment titleAlignment( void ) const;
 
-        //! button size
+        //* button size
         inline int buttonSize( void ) const;
 
-        //! frame border
+        //* frame border
         inline int frameBorder( void ) const;
 
-        //!@name status change methods (overloaded from KCommonDecorationUnstable)
+        //*@name status change methods (overloaded from KCommonDecorationUnstable)
         //@{
 
-        //! triggered when window activity is changed
+        //* triggered when window activity is changed
         virtual void activeChange();
 
-        //! triggered when maximize state changed
+        //* triggered when maximize state changed
         virtual void maximizeChange();
 
-        //! triggered when window shade is changed
+        //* triggered when window shade is changed
         virtual void shadeChange();
 
-        //! triggered when window shade is changed
+        //* triggered when window shade is changed
         virtual void captionChange();
 
         //@}
 
-        //! event filter
+        //* event filter
         virtual bool eventFilter( QObject*, QEvent* );
 
-        //! resize event
+        //* resize event
         virtual void resizeEvent( QResizeEvent* );
 
-        //! paint background to painter
+        //* paint background to painter
         void paintBackground( QPainter& ) const;
 
         public Q_SLOTS:
 
-        //! triggers widget update in titleRect only
-        /*! one needs to add the title top margin to avoid some clipping glitches */
+        //* triggers widget update in titleRect only
+        /** one needs to add the title top margin to avoid some clipping glitches */
         void updateTitleRect( void )
         { widget()->update( titleRect().adjusted( 0, -layoutMetric( LM_TitleEdgeTop ), 0, 1 ) ); }
 
-        //! return region for a given defines. This allows to implement extended borders
+        //* return region for a given defines. This allows to implement extended borders
         QRegion region( KDecorationDefines::Region );
 
         protected:
 
-        //! return shadow cache key associated to this client
+        //* return shadow cache key associated to this client
         ShadowCache::Key key( void ) const
         {
             ShadowCache::Key key;
@@ -257,104 +257,104 @@ namespace Oxygen
             return key;
         }
 
-        //! true when decoration is forced active
+        //* true when decoration is forced active
         void setForceActive( bool value )
         { _forceActive = value; }
 
-        //!@name event filters
+        //*@name event filters
         //@{
 
-        //! paint
+        //* paint
         virtual void paintEvent( QPaintEvent* );
 
-        //! render full decoration to provided painter
+        //* render full decoration to provided painter
         virtual void paint( QPainter& );
 
-        //! mouse press event
+        //* mouse press event
         virtual bool mousePressEvent( QMouseEvent* );
 
-        //! mouse release event
+        //* mouse release event
         virtual bool mouseReleaseEvent( QMouseEvent* );
 
-        //! mouse move event
+        //* mouse move event
         virtual bool mouseMoveEvent( QMouseEvent* );
 
-        //! drag enter event
+        //* drag enter event
         virtual bool dragEnterEvent( QDragEnterEvent* );
 
-        //! drag move event
+        //* drag move event
         virtual bool dragMoveEvent( QDragMoveEvent* );
 
-        //! drag leave event
+        //* drag leave event
         virtual bool dragLeaveEvent( QDragLeaveEvent* );
 
-        //! drop event
+        //* drop event
         virtual bool dropEvent( QDropEvent* );
 
-        //! timer event
+        //* timer event
         virtual void timerEvent( QTimerEvent* );
 
         //@}
 
-        //!@name rendering methods (called in paintEvent)
+        //*@name rendering methods (called in paintEvent)
         //@{
 
-        //! window background
+        //* window background
         virtual void renderWindowBackground( QPainter*, const QRect&, const QWidget*, const QPalette& ) const;
 
-        //! window border
+        //* window border
         // this draws a "blue" border around active window
         virtual void renderWindowBorder( QPainter*, const QRect&, const QWidget*, const QPalette& ) const;
 
-        //! separator
+        //* separator
         virtual void renderSeparator( QPainter*, const QRect&, const QWidget*, const QColor& ) const;
 
-        //! title outline
+        //* title outline
         virtual void renderTitleOutline( QPainter*, const QRect&, const QPalette& ) const;
 
-        //! title text
-        /*! second color, if valid, is for contrast pixel */
+        //* title text
+        /** second color, if valid, is for contrast pixel */
         virtual void renderTitleText( QPainter*, const QRect&, const QColor&, const QColor& = QColor() ) const;
 
-        //! title text
-        /*! second color, if valid, is for contrast pixel */
+        //* title text
+        /** second color, if valid, is for contrast pixel */
         virtual void renderTitleText( QPainter*, const QRect&, const QString&, const QColor&, const QColor& = QColor(), bool elide = true ) const;
 
-        //! title text
+        //* title text
         virtual QPixmap renderTitleText( const QRect&, const QString&, const QColor&, bool elide = true ) const;
 
-        //! GroupItem
+        //* GroupItem
         virtual void renderItem( QPainter*, int, const QPalette& );
 
-        //! tabbing target rect
+        //* tabbing target rect
         virtual void renderTargetRect( QPainter*, const QPalette& );
 
-        //! render corners
+        //* render corners
         virtual void renderCorners( QPainter*, const QRect&, const QPalette& ) const;
 
-        //! render float frame
+        //* render float frame
         virtual void renderFloatFrame( QPainter*, const QRect&, const QPalette& ) const;
 
-        //! render dots
+        //* render dots
         virtual void renderDots( QPainter*, const QRect&, const QColor& ) const;
 
         //@}
 
-        //! close tab matching give button
+        //* close tab matching give button
         virtual bool closeItem( const Button* );
 
-        //! index of item matching point
+        //* index of item matching point
         int tabIndexAt( const QPoint& position, bool between = false ) const
         { return _itemData.itemAt( position , between ); }
 
-        //! return pixmap corresponding to a given tab, for dragging
+        //* return pixmap corresponding to a given tab, for dragging
         QPixmap itemDragPixmap( int, QRect, bool = false );
 
-        //! return true when activity change are animated
+        //* return true when activity change are animated
         bool shadowAnimationsEnabled( void ) const
         { return ( animationsEnabled() && _configuration->shadowAnimationsEnabled() && !isPreview() ); }
 
-        //! return true when activity change are animated
+        //* return true when activity change are animated
         bool titleAnimationsEnabled( void ) const
         {
             return
@@ -365,7 +365,7 @@ namespace Oxygen
                 !isPreview();
         }
 
-        //! true if some title outline is rendered
+        //* true if some title outline is rendered
         bool hasTitleOutline( void ) const
         {
             return
@@ -374,64 +374,59 @@ namespace Oxygen
                 ( (isActive()||glowIsAnimated()) && _configuration->drawTitleOutline() );
         }
 
-        //! calculate mask
+        //* calculate mask
         QRegion calcMask( void ) const;
 
-        //! text color
+        //* text color
         QColor titlebarTextColor(const QPalette&) const;
 
-        //! text color
-        QColor titlebarTextColor(const QPalette& palette, bool active) const
-        {
-            return active ?
-                palette.color(QPalette::Active, QPalette::WindowText):
-                helper().inactiveTitleBarTextColor( palette );
-        }
+        //* text color
+        QColor titlebarTextColor(const QPalette& palette, bool windowActive, bool itemActive ) const;
 
-        //! text color
+        //* text color
         QColor titlebarContrastColor(const QPalette& palette ) const
         { return titlebarContrastColor( palette.color( widget()->window()->backgroundRole() ) ); }
 
-        //! text color
+        //* text color
         QColor titlebarContrastColor(const QColor& color ) const
         { return helper().calcLightColor( color ); }
 
-        //!@name size grip
+        //*@name size grip
         //@{
 
-        //! create size grip
+        //* create size grip
         void createSizeGrip( void );
 
-        //! delete size grip
+        //* delete size grip
         void deleteSizeGrip( void );
 
         // size grip
         bool hasSizeGrip( void ) const
         { return (bool)_sizeGrip; }
 
-        //! size grip
+        //* size grip
         SizeGrip& sizeGrip( void ) const
         { return *_sizeGrip; }
 
         //@}
 
-        //! remove shadow hint
+        //* remove shadow hint
         void removeShadowHint( void );
 
         protected Q_SLOTS:
 
-        //! set target item to -1
+        //* set target item to -1
         void clearTargetItem( void );
 
-        //! clear force active flag
+        //* clear force active flag
         void clearForceActive( void )
         { if( isActive() ) setForceActive( false ); }
 
-        //! title bounding rects
-        /*! calculate and return title bounding rects in case of tabbed window */
+        //* title bounding rects
+        /** calculate and return title bounding rects in case of tabbed window */
         void updateItemBoundingRects( bool alsoUpdate = true );
 
-        //! bound one rect to another
+        //* bound one rect to another
         void boundRectTo( QRect&, const QRect& ) const;
 
         private Q_SLOTS:
@@ -440,53 +435,53 @@ namespace Oxygen
 
         private:
 
-        //! factory
+        //* factory
         Factory* _factory;
 
-        //! backing store pixmap (when compositing is not active)
+        //* backing store pixmap (when compositing is not active)
         QPixmap _pixmap;
 
-        //! size grip widget
+        //* size grip widget
         SizeGrip* _sizeGrip;
 
-        //! configuration
+        //* configuration
         Factory::ConfigurationPtr _configuration;
 
-        //! glow animation
+        //* glow animation
         Animation* _glowAnimation;
 
-        //! title animation data
+        //* title animation data
         TitleAnimationData* _titleAnimationData;
 
-        //! glow intensity
+        //* glow intensity
         qreal _glowIntensity;
 
-        //! true when initialized
+        //* true when initialized
         bool _initialized;
 
-        //! true when decoration is forced active
+        //* true when decoration is forced active
         bool _forceActive;
 
-        //! mouse button
+        //* mouse button
         Qt::MouseButton _mouseButton;
 
-        //! tab bounding rects
+        //* tab bounding rects
         ClientGroupItemDataList _itemData;
 
-        //! index of tab being dragged if any, -1 otherwise
+        //* index of tab being dragged if any, -1 otherwise
         int _sourceItem;
 
-        //! drag start point
+        //* drag start point
         QPoint _dragPoint;
 
-        //! drag start timer.
-        /*!
+        //* drag start timer.
+        /**
         it is needed to activate animations when this was not done via either
         dragMoveEvent or dragLeaveEvent
         */
         QBasicTimer _dragStartTimer;
 
-        //! shadow atom
+        //* shadow atom
         xcb_atom_t _shadowAtom;
 
     };
